@@ -26,7 +26,7 @@ from xonsh.lazyimps import pygments, pyghooks
 from xonsh.imphooks import install_import_hooks
 from xonsh.events import events
 from xonsh.environ import xonshrc_context, make_args_env
-from xonsh.built_ins import XonshSession, load_builtins, load_proxies
+from xonsh.built_ins import XonshSession, load_builtins
 
 
 events.transmogrify("on_post_init", "LoadEvent")
@@ -257,7 +257,8 @@ def _pprint_displayhook(value):
         printed_val = repr(value)
     if HAS_PYGMENTS and env.get("COLOR_RESULTS"):
         tokens = list(pygments.lex(printed_val, lexer=pyghooks.XonshLexer()))
-        print_color(tokens)
+        end = "" if env.get("SHELL_TYPE") == "prompt_toolkit2" else "\n"
+        print_color(tokens, end=end)
     else:
         print(printed_val)  # black & white case
     builtins._ = value
@@ -307,11 +308,11 @@ def premain(argv=None):
     """Setup for main xonsh entry point. Returns parsed arguments."""
     if argv is None:
         argv = sys.argv[1:]
-    setup_timings()
+    builtins.__xonsh__ = XonshSession()
+    setup_timings(argv)
     setproctitle = get_setproctitle()
     if setproctitle is not None:
         setproctitle(" ".join(["xonsh"] + argv))
-    builtins.__xonsh__ = XonshSession()
     args = parser.parse_args(argv)
     if args.help:
         parser.print_help()
@@ -512,7 +513,6 @@ def setup(
         execer = Execer(xonsh_ctx=ctx)
         builtins.__xonsh__ = XonshSession(ctx=ctx, execer=execer)
         load_builtins(ctx=ctx, execer=execer)
-        load_proxies()
         builtins.__xonsh__.shell = Shell(execer, ctx=ctx, shell_type=shell_type)
     builtins.__xonsh__.env.update(env)
     install_import_hooks()
